==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.md <==
# AwsLicenseManagerLicenseBlending


```text
aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')
```



| Illustration | AwsLicenseManagerLicenseBlending | AwsLicenseManagerLicenseBlendingCard | AwsLicenseManagerLicenseBlendingGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.png) | ![illustration for AwsLicenseManagerLicenseBlending](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingCard](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingCard.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingGroup.Local.png) |




## AwsLicenseManagerLicenseBlending

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

## AwsLicenseManagerLicenseBlendingCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

## AwsLicenseManagerLicenseBlendingGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.md <==
# AwsLicenseManagerLicenseBlending


```text
aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')
```



| Illustration | AwsLicenseManagerLicenseBlending | AwsLicenseManagerLicenseBlendingCard | AwsLicenseManagerLicenseBlendingGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.png) | ![illustration for AwsLicenseManagerLicenseBlending](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingCard](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingCard.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingGroup.Local.png) |




## AwsLicenseManagerLicenseBlending

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

## AwsLicenseManagerLicenseBlendingCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

## AwsLicenseManagerLicenseBlendingGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-20210730/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
